# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/faststripe',
                'doc_host': 'https://AnswerDotAI.github.io',
                'git_url': 'https://github.com/AnswerDotAI/faststripe',
                'lib_path': 'faststripe'},
  'syms': { 'faststripe.core': { 'faststripe.core.StripeApi': ('core.html#stripeapi', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.__init__': ('core.html#stripeapi.__init__', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.find_prices': ('core.html#stripeapi.find_prices', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.find_product': ('core.html#stripeapi.find_product', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.one_time_payment': ( 'core.html#stripeapi.one_time_payment',
                                                                                 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.priced_product': ('core.html#stripeapi.priced_product', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.subscription': ('core.html#stripeapi.subscription', 'faststripe/core.py'),
                                 'faststripe.core._flatten_data': ('core.html#_flatten_data', 'faststripe/core.py'),
                                 'faststripe.core._mk_func': ('core.html#_mk_func', 'faststripe/core.py'),
                                 'faststripe.core._parse_operation_id': ('core.html#_parse_operation_id', 'faststripe/core.py')},
            'faststripe.endpoints': {},
            'faststripe.spec': { 'faststripe.spec.stripe_endpoints': ('spec.html#stripe_endpoints', 'faststripe/spec.py'),
                                 'faststripe.spec.update_version': ('spec.html#update_version', 'faststripe/spec.py')}}}
